summaryrefslogtreecommitdiff
path: root/include/ap_expr.h
diff options
context:
space:
mode:
authorStefan Fritsch <sf@apache.org>2010-11-26 19:32:13 +0000
committerStefan Fritsch <sf@apache.org>2010-11-26 19:32:13 +0000
commitc409988d423bca50a0cab95051554b2aeef6827d (patch)
tree31b3f19a7fa9e86f3a1863a983bc2bac53ac2a12 /include/ap_expr.h
parentc954d61ebbfcf9e61c8c2cec37630dc0af7ab743 (diff)
downloadhttpd-c409988d423bca50a0cab95051554b2aeef6827d.tar.gz
Fix another Windows build issue: Add a wrapper around ap_run_expr_lookup with
the correct calling convention. git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@1039528 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/ap_expr.h')
-rw-r--r--include/ap_expr.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/include/ap_expr.h b/include/ap_expr.h
index f71f8817bb..dbfff1302e 100644
--- a/include/ap_expr.h
+++ b/include/ap_expr.h
@@ -121,14 +121,15 @@ typedef struct {
/**
- * The parse can be extended with variable lookup, functions, and
+ * The parser can be extended with variable lookup, functions, and
* and operators.
*
* During parsing, the parser calls the lookup function to resolve a
* name into a function pointer and an opaque context for the function.
*
* The default lookup function is the hook 'ap_run_expr_lookup'.
* Modules can use it to make functions and variables generally available.
*
* An ap_expr consumer can also provide its own custom lookup function to
* modify the set of variables and functions that are available. The custom
@@ -217,6 +218,12 @@ typedef struct {
*/
typedef int (ap_expr_lookup_fn)(ap_expr_lookup_parms *parms);
+/** Default lookup function which just calls ap_run_expr_lookup().
+ * ap_run_expr_lookup cannot be used directly because it has the wrong
+ * calling convention under Windows.
+ */
+AP_DECLARE_NONSTD(int) ap_expr_lookup_default(ap_expr_lookup_parms *parms);
+
AP_DECLARE_HOOK(int, expr_lookup, (ap_expr_lookup_parms *parms))
/**
@@ -121,14 +121,15 @@ typedef struct {
* name into a function pointer and an opaque context for the function.
*
- * The default lookup function is the hook 'ap_run_expr_lookup'.
- * Modules can use it to make functions and variables generally available.
+ * The default lookup function is the hook 'ap_expr_lookup_default' which just
+ * calls ap_expr_lookup_default. Modules can use it to make functions and
+ * variables generally available.
*
* An ap_expr consumer can also provide its own custom lookup function to